v0.1.1 (2014-10-27)
-------------------

- [breaking change] new languages format on the command-line. The previous one
  used ``-f`` and ``-t`` options, the new one is more compact: ::

    $ wptranslate -f source -t target word  # previous format
    $ wptranslate source:target word        # new format


v0.1.0 (2014-10-02)
-------------------

- initial release
